# Development Information

* Default ODBC driver is 'AspenTech SQLplus'
* `IP_DCS_NAME` property is not available accross all systems
* Testing SQL Server connection string - `DRIVER=ODBC Driver 18 for SQL Server;SERVER=localhost;DATABASE=master;PORT=1433;UID=sa;PWD=Contraseña12345678;ENCRYPT=NO`
